@@ -14,9 +14,9 @@ class BlockCallbackFilter:
         self.filters.append(fltr)
 
 
-    def filter(self, block, tx=None):
+    def filter(self, conn, block):
         for fltr in self.filters:
-            fltr.filter(block, tx=tx)
+            fltr.filter(conn, block)
 
 
 def state_change_callback(k, old_state, new_state):
@@ -27,13 +27,13 @@ def filter_change_callback(k, old_state, new_state):
     logg.log(logging.STATETRACE, 'filter change: {} {} -> {}'.format(k, old_state, new_state)) 
 
 
-def pre_callback():
+def pre_callback(conn):
     logg.debug('starting sync loop iteration')
 
 
-def post_callback():
+def post_callback(conn):
     logg.debug('ending sync loop iteration')
 
 
-def block_callback(block, tx):
+def block_callback(conn, block):
     logg.info('processing {} {}'.format(block, datetime.datetime.fromtimestamp(block.timestamp)))
