@@ -15,14 +15,14 @@ class Filter(RuledFilter):
         self.include_tx_data = include_tx_data
 
 
-    def ruled_filter(self, conn, block, tx, db_session=None):
+    def ruled_filter(self, conn, block, tx, **kwargs):
         self.store.put_tx(tx, include_data=self.include_tx_data)
 
 
-    def filter(self, conn, block, tx, db_session=None):
-        r = super(Filter, self).filter(conn, block, tx, db_session=db_session)
+    def filter(self, conn, block, tx, **kwargs):
+        r = super(Filter, self).filter(conn, block, tx, **kwargs)
         if r == True:
             return True
 
-        self.ruled_filter(conn, block, tx, db_session=db_session)
+        self.ruled_filter(conn, block, tx, **kwargs)
         return False
